<p align="center">
    <a href="#"><img src="https://raw.githubusercontent.com/ManimEditorProject/manim_editor/main/manim_editor/app/static/img/banner.png"></a>
    <br />
    <br />
    <a href="https://pypi.org/project/manim-editor/"><img src="https://img.shields.io/pypi/v/manim-editor.svg?style=flat&logo=pypi" alt="PyPI Latest Release"></a>
    <a href="https://manim-editor.readthedocs.io/en/stable/"><img src='https://readthedocs.org/projects/manim-editor/badge/?version=stable' alt='Documentation Status' /></a>
    <a href="http://choosealicense.com/licenses/mit/"><img src="https://img.shields.io/badge/license-MIT-red.svg?style=flat" alt="MIT License"></a>
    <a href="https://github.com/ManimEditorProject/manim_editor/actions/workflows/build_pages.yml"><img src="https://github.com/ManimEditorProject/manim_editor/actions/workflows/build_pages.yml/badge.svg" alt="MIT License"></a>
    <br />
    <br />
    <i>Editor and Presenter for Manim Generated Content.</i>
</p>
<hr />

Take a look at the [Working Example](https://manimeditorproject.github.io/manim_editor/).
More information can be found on the [documentation](https://manim-editor.readthedocs.io/en/stable/).

These Browsers are supported:
- Firefox
- Chrome
- Edge

## Create a Project

![create_project](https://raw.githubusercontent.com/ManimEditorProject/manim_editor/main/docs/source/_static/create_project.gif)

## Export a Project as a Presentation

![export_presenter](https://raw.githubusercontent.com/ManimEditorProject/manim_editor/main/docs/source/_static/export_presenter.gif)
